# This nginx service will replace the beta host so that 
# we leverage nginx as a reverse proxy in fargate instead

resource "aws_ecs_task_definition" "beta" {
  for_each = toset(local.buckets)
  family = "${var.athens_prefix}-beta"

  network_mode = "awsvpc"
  requires_compatibilities = ["FARGATE"]
  execution_role_arn = aws_iam_role.alpha_iam_role.arn

  cpu = 256
  memory = 512

  container_definitions = jsonencode([
    {
      name = "${var.athens_prefix}-${replace(each.value, ".", "-")}"
      image = "805875567437.dkr.ecr.us-west-1.amazonaws.com/reverse-proxy:latest"
      cpu = 256
      memory = 512
      essential = true
      environment = [
        { name = "S3_ACCESS_KEY_ID",  value = var.shockrah_xyz_s3_access_key_id },
        { name = "S3_SECRET_KEY",     value = var.shockrah_xyz_s3_secret_key },
        { name = "S3_REGION",         value = var.aws_region },
        { name = "S3_SERVER",         value = "s3-${var.aws_region}.amazonaws.com" },
        { name = "S3_BUCKET_NAME",    value = each.value },
      ]
      portMappings = [
        { 
          containerPort = var.nginx_port, 
          hostPort = var.nginx_port
        }
      ]
      logConfiguration = {
        logDriver = "awslogs"
        options = {
          awslogs-group  = aws_cloudwatch_log_group.alpha.name
          awslogs-region = "us-west-1"
          awslogs-stream-prefix  = "beta-container"
        }
      }
    }
  ])
  tags = {
    Name        = "${var.athens_prefix}-beta-task-def-container"
    Description = "Reverse proxy for all static content"
  }
}

resource "aws_ecs_service" "beta_reverse_proxy" {
  for_each = toset(local.buckets)

  name              = "${var.athens_prefix}-proxy-${replace(each.value, ".", "-")}"
  cluster           = aws_ecs_cluster.alpha.id
  task_definition   = aws_ecs_task_definition.beta[each.value].arn
  desired_count     = 1
  launch_type       = "FARGATE"
  load_balancer {
    target_group_arn  = aws_lb_target_group.nginx[each.value].arn
    container_name    = "${var.athens_prefix}-${replace(each.value, ".", "-")}"
    container_port    = var.nginx_port
  }

  network_configuration {
    assign_public_ip  = true
    subnets = [
      aws_subnet.delphi.id,
      aws_subnet.crete_subnet.id,
    ]
    security_groups = [
      aws_security_group.ecs_web_ingress.id,
      aws_security_group.base_ecs.id,
    ]
  }
  depends_on = [
    aws_lb_target_group.nginx
  ]
}
